#line 1 "ad_riscv_pipeline.cpp"
//
// Copyright (c) 2003, 2020, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2014, 2020, Red Hat Inc. All rights reserved.
// Copyright (c) 2020, 2022, Huawei Technologies Co., Ltd. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/ad_riscv.hpp"

//------------------Pipeline Methods-----------------------------------------
#ifndef PRODUCT
const char * Pipeline::stageName(uint s) {
  static const char * const _stage_names[] = {
    "undefined", "S0", "S1", "S2", "S3", "S4", "S5"
  };

  return (s <= 6 ? _stage_names[s] : "???");
}
#endif

uint Pipeline::functional_unit_latency(uint start, const Pipeline *pred) const {
  // See if the functional units overlap
  uint mask = resourcesUsedExclusively() & pred->resourcesUsedExclusively();
  if (mask == 0)
    return (start);

  for (uint i = 0; i < pred->resourceUseCount(); i++) {
    const Pipeline_Use_Element *predUse = pred->resourceUseElement(i);
    if (predUse->multiple())
      continue;

    for (uint j = 0; j < resourceUseCount(); j++) {
      const Pipeline_Use_Element *currUse = resourceUseElement(j);
      if (currUse->multiple())
        continue;

      if (predUse->used() & currUse->used()) {
        Pipeline_Use_Cycle_Mask x = predUse->mask();
        Pipeline_Use_Cycle_Mask y = currUse->mask();

        for ( y <<= start; x.overlaps(y); start++ )
          y <<= 1;
      }
    }
  }

  // There is the potential for overlap
  return (start);
}

// The following two routines assume that the root Pipeline_Use entity
// consists of exactly 1 element for each functional unit
// start is relative to the current cycle; used for latency-based info
uint Pipeline_Use::full_latency(uint delay, const Pipeline_Use &pred) const {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      uint min_delay = 7;
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        uint curr_delay = delay;
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= curr_delay; x.overlaps(y); curr_delay++ )
            y <<= 1;
        }
        if (min_delay > curr_delay)
          min_delay = curr_delay;
      }
      if (delay < min_delay)
      delay = min_delay;
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= delay; x.overlaps(y); delay++ )
            y <<= 1;
        }
      }
    }
  }

  return (delay);
}

void Pipeline_Use::add_usage(const Pipeline_Use &pred) {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        if ( !predUse->_mask.overlaps(currUse->_mask) ) {
          currUse->_used |= (1 << j);
          _resources_used |= (1 << j);
          currUse->_mask.Or(predUse->_mask);
          break;
        }
      }
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        currUse->_used |= (1 << j);
        _resources_used |= (1 << j);
        currUse->_mask.Or(predUse->_mask);
      }
    }
  }
}

uint Pipeline::operand_latency(uint opnd, const Pipeline *pred) const {
  int const default_latency = 1;

  assert(this, "NULL pipeline info");
  assert(pred, "NULL predecessor pipline info");

  if (pred->hasFixedLatency())
    return (pred->fixedLatency());

  // If this is not an operand, then assume a dependence with 0 latency
  if (opnd > _read_stage_count)
    return (0);

  uint writeStage = pred->_write_stage;
  uint readStage  = _read_stages[opnd-1];

  if (writeStage == stage_undefined || readStage == stage_undefined)
    return (default_latency);

  int delta = writeStage - readStage;
  if (delta < 0) delta = 0;

  return (delta);
}

Pipeline_Use_Cycle_Mask operator&(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask & in2._mask);
}

Pipeline_Use_Cycle_Mask operator|(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask | in2._mask);
}

static const Pipeline pipeline_class_Zero_Instructions(0, 0, true, 0, 0, false, false, false, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

static const Pipeline pipeline_class_Unknown_Instructions(0, 0, true, 0, 0, false, true, true, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

const Pipeline_Use_Element Pipeline_Use::elaborated_elements[7] = {
  Pipeline_Use_Element(0, 0, 0, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 1, 1, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 2, 2, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 3, 3, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 4, 4, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 5, 5, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 6, 6, false, Pipeline_Use_Cycle_Mask(0))
};

const Pipeline_Use Pipeline_Use::elaborated_use(0, 0, 7, (Pipeline_Use_Element *)&elaborated_elements[0]);


// Pipeline Class "fp_dop_reg_reg_s"
static const enum machPipelineStages pipeline_reads_001[2] = {
  stage_S1,
  stage_S2 
};

static const enum machPipelineStages pipeline_res_stages_001[7] = {
  stage_S0,        // DECODE
  stage_undefined, // ALU
  stage_undefined, // MUL
  stage_undefined, // DIV
  stage_undefined, // BRANCH
  stage_undefined, // LDST
  stage_S5         // FPU
};

static const uint pipeline_res_cycles_001[7] = {
  1, // DECODE
  0, // ALU
  0, // MUL
  0, // DIV
  0, // BRANCH
  0, // LDST
  1  // FPU
};

static const Pipeline_Use_Element pipeline_res_mask_001[2] = {
  Pipeline_Use_Element(0x01, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x40, 6, 6, false, Pipeline_Use_Cycle_Mask(0x00000010)) 
};

static const Pipeline pipeline_class_001((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_dop_reg_reg_d"
static const Pipeline pipeline_class_002((uint)stage_S5, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_uop_s"
static const enum machPipelineStages pipeline_reads_002[1] = {
  stage_S1 
};

static const Pipeline pipeline_class_003((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_uop_d"
static const Pipeline pipeline_class_004((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_d2f"
static const Pipeline pipeline_class_005((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_f2d"
static const Pipeline pipeline_class_006((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_f2i"
static const Pipeline pipeline_class_007((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_f2l"
static const Pipeline pipeline_class_008((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_i2f"
static const Pipeline pipeline_class_009((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_l2f"
static const Pipeline pipeline_class_010((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_d2i"
static const Pipeline pipeline_class_011((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_d2l"
static const Pipeline pipeline_class_012((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_i2d"
static const Pipeline pipeline_class_013((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_l2d"
static const Pipeline pipeline_class_014((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_div_s"
static const Pipeline pipeline_class_015((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_div_d"
static const Pipeline pipeline_class_016((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_sqrt_s"
static const Pipeline pipeline_class_017((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_sqrt_d"
static const Pipeline pipeline_class_018((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_load_constant_s"
static const Pipeline pipeline_class_019((uint)stage_S5, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_load_constant_d"
static const Pipeline pipeline_class_020((uint)stage_S5, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x41, 0x41, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_load_mem_s"
static const enum machPipelineStages pipeline_res_stages_002[7] = {
  stage_S0,        // DECODE
  stage_undefined, // ALU
  stage_undefined, // MUL
  stage_undefined, // DIV
  stage_undefined, // BRANCH
  stage_S2,        // LDST
  stage_undefined  // FPU
};

static const uint pipeline_res_cycles_002[7] = {
  1, // DECODE
  0, // ALU
  0, // MUL
  0, // DIV
  0, // BRANCH
  1, // LDST
  0  // FPU
};

static const Pipeline_Use_Element pipeline_res_mask_002[2] = {
  Pipeline_Use_Element(0x01, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x20, 5, 5, false, Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_021((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "fp_load_mem_d"
static const Pipeline pipeline_class_022((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "fp_store_reg_s"
static const enum machPipelineStages pipeline_reads_003[2] = {
  stage_S1,
  stage_S5 
};

static const Pipeline pipeline_class_023((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "fp_store_reg_d"
static const Pipeline pipeline_class_024((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "ialu_reg_reg"
static const enum machPipelineStages pipeline_reads_004[2] = {
  stage_S0,
  stage_S0 
};

static const enum machPipelineStages pipeline_res_stages_003[7] = {
  stage_S0,        // DECODE
  stage_S1,        // ALU
  stage_undefined, // MUL
  stage_undefined, // DIV
  stage_undefined, // BRANCH
  stage_undefined, // LDST
  stage_undefined  // FPU
};

static const uint pipeline_res_cycles_003[7] = {
  1, // DECODE
  1, // ALU
  0, // MUL
  0, // DIV
  0, // BRANCH
  0, // LDST
  0  // FPU
};

static const Pipeline_Use_Element pipeline_res_mask_003[2] = {
  Pipeline_Use_Element(0x01, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x02, 1, 1, false, Pipeline_Use_Cycle_Mask(0x00000001)) 
};

static const Pipeline pipeline_class_025((uint)stage_S1, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x3, 0x3, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_reg_shift"
static const enum machPipelineStages pipeline_reads_005[1] = {
  stage_S0 
};

static const Pipeline pipeline_class_026((uint)stage_S1, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x3, 0x3, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_reg_reg_vshift"
static const Pipeline pipeline_class_027((uint)stage_S1, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x3, 0x3, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_reg"
static const Pipeline pipeline_class_028((uint)stage_S1, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x3, 0x3, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_reg_imm"
static const Pipeline pipeline_class_029((uint)stage_S1, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x3, 0x3, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_imm"
static const Pipeline pipeline_class_030((uint)stage_S1, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x3, 0x3, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "imul_reg_reg"
static const enum machPipelineStages pipeline_res_stages_004[7] = {
  stage_S0,        // DECODE
  stage_undefined, // ALU
  stage_S3,        // MUL
  stage_undefined, // DIV
  stage_undefined, // BRANCH
  stage_undefined, // LDST
  stage_undefined  // FPU
};

static const uint pipeline_res_cycles_004[7] = {
  1, // DECODE
  0, // ALU
  1, // MUL
  0, // DIV
  0, // BRANCH
  0, // LDST
  0  // FPU
};

static const Pipeline_Use_Element pipeline_res_mask_004[2] = {
  Pipeline_Use_Element(0x01, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x04, 2, 2, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_031((uint)stage_S3, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x5, 0x5, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "lmul_reg_reg"
static const Pipeline pipeline_class_032((uint)stage_S3, 2, true, 3, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x5, 0x5, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "idiv_reg_reg"
static const enum machPipelineStages pipeline_res_stages_005[7] = {
  stage_S0,        // DECODE
  stage_undefined, // ALU
  stage_undefined, // MUL
  stage_S3,        // DIV
  stage_undefined, // BRANCH
  stage_undefined, // LDST
  stage_undefined  // FPU
};

static const uint pipeline_res_cycles_005[7] = {
  1, // DECODE
  0, // ALU
  0, // MUL
  1, // DIV
  0, // BRANCH
  0, // LDST
  0  // FPU
};

static const Pipeline_Use_Element pipeline_res_mask_005[2] = {
  Pipeline_Use_Element(0x01, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x08, 3, 3, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_033((uint)stage_S3, 2, true, 8, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x9, 0x9, 2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "ldiv_reg_reg"
static const Pipeline pipeline_class_034((uint)stage_S3, 2, true, 16, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x9, 0x9, 2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "iload_reg_mem"
static const Pipeline pipeline_class_035((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "iload_reg_reg"
static const Pipeline pipeline_class_036((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "istore_mem"
static const Pipeline pipeline_class_037((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "istore_reg_mem"
static const enum machPipelineStages pipeline_reads_006[2] = {
  stage_S1,
  stage_S0 
};

static const Pipeline pipeline_class_038((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_006,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "istore_reg_reg"
static const enum machPipelineStages pipeline_reads_007[2] = {
  stage_S0,
  stage_S1 
};

static const Pipeline pipeline_class_039((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "pipe_branch"
static const enum machPipelineStages pipeline_res_stages_006[7] = {
  stage_S0,        // DECODE
  stage_undefined, // ALU
  stage_undefined, // MUL
  stage_undefined, // DIV
  stage_S1,        // BRANCH
  stage_undefined, // LDST
  stage_undefined  // FPU
};

static const uint pipeline_res_cycles_006[7] = {
  1, // DECODE
  0, // ALU
  0, // MUL
  0, // DIV
  1, // BRANCH
  0, // LDST
  0  // FPU
};

static const Pipeline_Use_Element pipeline_res_mask_006[2] = {
  Pipeline_Use_Element(0x01, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x10, 4, 4, false, Pipeline_Use_Cycle_Mask(0x00000001)) 
};

static const Pipeline pipeline_class_040((uint)stage_undefined, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x11, 0x11, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "pipe_branch_reg"
static const Pipeline pipeline_class_041((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x11, 0x11, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "pipe_cmp_branch"
static const Pipeline pipeline_class_042((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x11, 0x11, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "pipe_cmpz_branch"
static const Pipeline pipeline_class_043((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x11, 0x11, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "pipe_serial"
static const Pipeline pipeline_class_044((uint)stage_undefined, 0, true, 16, 1, false, false, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "pipe_slow"
static const Pipeline pipeline_class_045((uint)stage_undefined, 0, true, 16, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x21, 0x21, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "pipe_class_empty"
static const enum machPipelineStages pipeline_res_stages_007[7] = {
  stage_undefined, // DECODE
  stage_undefined, // ALU
  stage_undefined, // MUL
  stage_undefined, // DIV
  stage_undefined, // BRANCH
  stage_undefined, // LDST
  stage_undefined  // FPU
};

static const uint pipeline_res_cycles_007[7] = {
  0, // DECODE
  0, // ALU
  0, // MUL
  0, // DIV
  0, // BRANCH
  0, // LDST
  0  // FPU
};

static const Pipeline pipeline_class_046((uint)stage_undefined, 0, true, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_default"
static const Pipeline pipeline_class_047((uint)stage_undefined, 0, true, 2, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_compare"
static const Pipeline pipeline_class_048((uint)stage_undefined, 0, true, 16, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_memory"
static const Pipeline pipeline_class_049((uint)stage_undefined, 0, true, 16, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_call"
static const Pipeline pipeline_class_050((uint)stage_undefined, 0, true, 100, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x0, 0x0, 0, (Pipeline_Use_Element *)NULL));

//------------------Inter-Instruction Latency--------------------------------
uint Node::latency(uint i) {
  uint j;
  // verify in legal range for inputs
  assert(i < len(), "index not in range");

  // verify input is not null
  Node *pred = in(i);
  if (!pred)
    return 0;

  if (pred->is_Proj())
    pred = pred->in(0);

  // if either node does not have pipeline info, use default
  const Pipeline *predpipe = pred->pipeline();
  assert(predpipe, "no predecessor pipeline info");

  if (predpipe->hasFixedLatency())
    return predpipe->fixedLatency();

  const Pipeline *currpipe = pipeline();
  assert(currpipe, "no pipeline info");

  if (!is_Mach())
    return 0;

  const MachNode *m = as_Mach();
  j = m->oper_input_base();
  if (i < j)
    return currpipe->functional_unit_latency(0, predpipe);

  // determine which operand this is in
  uint n = m->num_opnds();
  int delta = 0;

  uint k;
  for (k = 1; k < n; k++) {
    j += m->_opnds[k]->num_edges();
    if (i < j)
      break;
  }
  if (k < n)
    delta = currpipe->operand_latency(k,predpipe);

  return currpipe->functional_unit_latency(delta, predpipe);
}

// Descriptions for emitting different functional unit nops
void Bundle::initialize_nops(MachNode * nop_list[1]) {
  nop_list[0] = (MachNode *) new MachNopNode();
};

#ifndef PRODUCT
void Bundle::dump(outputStream *st) const {
  static const char * bundle_flags[] = {
    "",
    "use nop delay",
    "use unconditional delay",
    "use conditional delay",
    "used in conditional delay",
    "used in unconditional delay",
    "used in all conditional delays",
  };

  static const char *resource_names[7] = { "DECODE", "ALU", "MUL", "DIV", "BRANCH", "LDST", "FPU" };

  bool needs_comma = false;

  if (_flags) {
    st->print("%s", bundle_flags[_flags]);
    needs_comma = true;
  };
  if (instr_count()) {
    st->print("%s%d instr%s", needs_comma ? ", " : "", instr_count(), instr_count() != 1 ? "s" : "");
    needs_comma = true;
  };
  uint r = resources_used();
  if (r) {
    st->print("%sresource%s:", needs_comma ? ", " : "", (r & (r-1)) != 0 ? "s" : "");
    for (uint i = 0; i < 7; i++)
      if ((r & (1 << i)) != 0)
        st->print(" %s", resource_names[i]);
    needs_comma = true;
  };
  st->print("\n");
}
#endif
const Pipeline *                              Node::pipeline_class() { return (&pipeline_class_Zero_Instructions); }
const Pipeline *                              Node::pipeline() const { return (&pipeline_class_Zero_Instructions); }

const Pipeline *                          MachNode::pipeline_class() { return (&pipeline_class_Unknown_Instructions); }
const Pipeline *                          MachNode::pipeline() const { return pipeline_class(); }

const Pipeline * MachNopNode::pipeline() const { return (&pipeline_class_046); }


const Pipeline *                             loadBNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                             loadBNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                           loadB2LNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                           loadB2LNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                            loadUBNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                            loadUBNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                          loadUB2LNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                          loadUB2LNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                             loadSNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                             loadSNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                           loadS2LNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                           loadS2LNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                            loadUSNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                            loadUSNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                          loadUS2LNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                          loadUS2LNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                             loadINode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                             loadINode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                           loadI2LNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                           loadI2LNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                          loadUI2LNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                          loadUI2LNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                             loadLNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                             loadLNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                         loadRangeNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                         loadRangeNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                             loadPNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                             loadPNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                             loadNNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                             loadNNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                         loadKlassNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                         loadKlassNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                        loadNKlassNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                        loadNKlassNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                             loadFNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                             loadFNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                             loadDNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                             loadDNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                          loadConINode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                          loadConINode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                          loadConLNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                          loadConLNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                          loadConPNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                          loadConPNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                         loadConP0Node::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                         loadConP0Node::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                         loadConP1Node::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                         loadConP1Node::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                   loadByteMapBaseNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                   loadByteMapBaseNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                          loadConNNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                          loadConNNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                         loadConN0Node::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                         loadConN0Node::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                     loadConNKlassNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                     loadConNKlassNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                          loadConFNode::pipeline_class() { return (&pipeline_class_019); }
const Pipeline *                          loadConFNode::pipeline() const { return (&pipeline_class_019); }

const Pipeline *                         loadConF0Node::pipeline_class() { return (&pipeline_class_019); }
const Pipeline *                         loadConF0Node::pipeline() const { return (&pipeline_class_019); }

const Pipeline *                          loadConDNode::pipeline_class() { return (&pipeline_class_020); }
const Pipeline *                          loadConDNode::pipeline() const { return (&pipeline_class_020); }

const Pipeline *                         loadConD0Node::pipeline_class() { return (&pipeline_class_020); }
const Pipeline *                         loadConD0Node::pipeline() const { return (&pipeline_class_020); }

const Pipeline *                       storeimmCM0Node::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *                       storeimmCM0Node::pipeline() const { return (&pipeline_class_037); }

const Pipeline *               storeimmCM0_orderedNode::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *               storeimmCM0_orderedNode::pipeline() const { return (&pipeline_class_037); }

const Pipeline *                            storeBNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                            storeBNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        storeimmB0Node::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *                        storeimmB0Node::pipeline() const { return (&pipeline_class_037); }

const Pipeline *                            storeCNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                            storeCNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        storeimmC0Node::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *                        storeimmC0Node::pipeline() const { return (&pipeline_class_037); }

const Pipeline *                            storeINode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                            storeINode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        storeimmI0Node::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *                        storeimmI0Node::pipeline() const { return (&pipeline_class_037); }

const Pipeline *                            storeLNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                            storeLNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        storeimmL0Node::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *                        storeimmL0Node::pipeline() const { return (&pipeline_class_037); }

const Pipeline *                            storePNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                            storePNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        storeimmP0Node::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *                        storeimmP0Node::pipeline() const { return (&pipeline_class_037); }

const Pipeline *                            storeNNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                            storeNNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        storeImmN0Node::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                        storeImmN0Node::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                            storeFNode::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                            storeFNode::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                            storeDNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                            storeDNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                       storeNKlassNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                       storeNKlassNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                       loadPLockedNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                       loadPLockedNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                 storePConditionalNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                 storePConditionalNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                 storeLConditionalNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                 storeLConditionalNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                 storeIConditionalNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                 storeIConditionalNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   compareAndSwapBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   compareAndSwapBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   compareAndSwapSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   compareAndSwapSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   compareAndSwapINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   compareAndSwapINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   compareAndSwapLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   compareAndSwapLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   compareAndSwapPNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   compareAndSwapPNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   compareAndSwapNNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   compareAndSwapNNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                compareAndSwapBAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                compareAndSwapBAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                compareAndSwapSAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                compareAndSwapSAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                compareAndSwapIAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                compareAndSwapIAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                compareAndSwapLAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                compareAndSwapLAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                compareAndSwapPAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                compareAndSwapPAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                compareAndSwapNAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                compareAndSwapNAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               compareAndExchangeBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               compareAndExchangeBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               compareAndExchangeSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               compareAndExchangeSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               compareAndExchangeINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               compareAndExchangeINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               compareAndExchangeLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               compareAndExchangeLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               compareAndExchangeNNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               compareAndExchangeNNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               compareAndExchangePNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               compareAndExchangePNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            compareAndExchangeBAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            compareAndExchangeBAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            compareAndExchangeSAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            compareAndExchangeSAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            compareAndExchangeIAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            compareAndExchangeIAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            compareAndExchangeLAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            compareAndExchangeLAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            compareAndExchangeNAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            compareAndExchangeNAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            compareAndExchangePAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            compareAndExchangePAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               weakCompareAndSwapBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               weakCompareAndSwapBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               weakCompareAndSwapSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               weakCompareAndSwapSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               weakCompareAndSwapINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               weakCompareAndSwapINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               weakCompareAndSwapLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               weakCompareAndSwapLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               weakCompareAndSwapNNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               weakCompareAndSwapNNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               weakCompareAndSwapPNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               weakCompareAndSwapPNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            weakCompareAndSwapBAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            weakCompareAndSwapBAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            weakCompareAndSwapSAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            weakCompareAndSwapSAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            weakCompareAndSwapIAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            weakCompareAndSwapIAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            weakCompareAndSwapLAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            weakCompareAndSwapLAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            weakCompareAndSwapNAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            weakCompareAndSwapNAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *            weakCompareAndSwapPAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *            weakCompareAndSwapPAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      get_and_setINode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                      get_and_setINode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                      get_and_setLNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                      get_and_setLNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                      get_and_setNNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                      get_and_setNNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                      get_and_setPNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                      get_and_setPNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                   get_and_setIAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                   get_and_setIAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                   get_and_setLAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                   get_and_setLAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                   get_and_setNAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                   get_and_setNAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                   get_and_setPAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                   get_and_setPAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                      get_and_addLNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                      get_and_addLNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *               get_and_addL_no_resNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *               get_and_addL_no_resNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                     get_and_addLiNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                     get_and_addLiNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *              get_and_addLi_no_resNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *              get_and_addLi_no_resNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                      get_and_addINode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                      get_and_addINode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *               get_and_addI_no_resNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *               get_and_addI_no_resNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                     get_and_addIiNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                     get_and_addIiNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *              get_and_addIi_no_resNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *              get_and_addIi_no_resNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                   get_and_addLAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                   get_and_addLAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *            get_and_addL_no_resAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *            get_and_addL_no_resAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                  get_and_addLiAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                  get_and_addLiAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *           get_and_addLi_no_resAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *           get_and_addLi_no_resAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                   get_and_addIAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                   get_and_addIAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *            get_and_addI_no_resAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *            get_and_addI_no_resAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                  get_and_addIiAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                  get_and_addIiAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *           get_and_addIi_no_resAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *           get_and_addIi_no_resAcqNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                      addI_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      addI_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      addI_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      addI_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                  addI_reg_imm_l2iNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                  addI_reg_imm_l2iNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      addP_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      addP_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *              lShiftL_regI_immGE32Node::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *              lShiftL_regI_immGE32Node::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                      addP_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      addP_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      addL_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      addL_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      addL_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      addL_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      subI_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      subI_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      subI_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      subI_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      subL_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      subL_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      subL_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      subL_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                          negI_regNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                          negI_regNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                          negL_regNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                          negL_regNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                              mulINode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                              mulINode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                              mulLNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                              mulLNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                       mulHiL_rRegNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                       mulHiL_rRegNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                              divINode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                              divINode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                       signExtractNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                       signExtractNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                              divLNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                              divLNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                      signExtractLNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                      signExtractLNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                              modINode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                              modINode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                              modLNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                              modLNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                   lShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                   lShiftI_reg_regNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                   lShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                   lShiftI_reg_immNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                  urShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                  urShiftI_reg_regNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                  urShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                  urShiftI_reg_immNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                   rShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                   rShiftI_reg_regNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                   rShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                   rShiftI_reg_immNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                   lShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                   lShiftL_reg_regNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                   lShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                   lShiftL_reg_immNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                  urShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                  urShiftL_reg_regNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                  urShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                  urShiftL_reg_immNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                  urShiftP_reg_immNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                  urShiftP_reg_immNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                   rShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                   rShiftL_reg_regNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                   rShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                   rShiftL_reg_immNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                      regI_not_regNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      regI_not_regNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      regL_not_regNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      regL_not_regNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      addF_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      addF_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      addD_reg_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                      addD_reg_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                      subF_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      subF_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      subD_reg_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                      subD_reg_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                      mulF_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      mulF_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      mulD_reg_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                      mulD_reg_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                     maddF_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     maddF_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                     maddD_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     maddD_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                     msubF_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     msubF_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                     msubD_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     msubD_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                    nmsubF_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                    nmsubF_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                  nmsubF_reg_reg_0Node::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                  nmsubF_reg_reg_0Node::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                    nmsubD_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                    nmsubD_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                  nmsubD_reg_reg_0Node::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                  nmsubD_reg_reg_0Node::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                    nmaddF_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                    nmaddF_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                  nmaddF_reg_reg_0Node::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                  nmaddF_reg_reg_0Node::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                    nmaddD_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                    nmaddD_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                  nmaddD_reg_reg_0Node::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                  nmaddD_reg_reg_0Node::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                      maxF_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                      maxF_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                      minF_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                      minF_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                      maxD_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                      maxD_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                      minD_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                      minD_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                      divF_reg_regNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                      divF_reg_regNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                      divD_reg_regNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                      divD_reg_regNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                      negF_reg_regNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                      negF_reg_regNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                      negD_reg_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *                      negD_reg_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *                          absI_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                          absI_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                          absL_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                          absL_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                          absF_regNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                          absF_regNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                          absD_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *                          absD_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *                         sqrtF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                         sqrtF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                         sqrtD_regNode::pipeline_class() { return (&pipeline_class_018); }
const Pipeline *                         sqrtD_regNode::pipeline() const { return (&pipeline_class_018); }

const Pipeline *                      andI_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      andI_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      andI_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      andI_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                       orI_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                       orI_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                       orI_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                       orI_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      xorI_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      xorI_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      xorI_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      xorI_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      andL_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      andL_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      andL_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      andL_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                       orL_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                       orL_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                       orL_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                       orL_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      xorL_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      xorL_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      xorL_reg_immNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                      xorL_reg_immNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                 bytes_reverse_intNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                 bytes_reverse_intNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                bytes_reverse_longNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                bytes_reverse_longNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *      bytes_reverse_unsigned_shortNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *      bytes_reverse_unsigned_shortNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *               bytes_reverse_shortNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *               bytes_reverse_shortNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                        load_fenceNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                        load_fenceNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                    membar_acquireNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                    membar_acquireNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *               membar_acquire_lockNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *               membar_acquire_lockNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                       store_fenceNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                       store_fenceNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                    membar_releaseNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                    membar_releaseNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                 membar_storestoreNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                 membar_storestoreNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *               membar_storestore_0Node::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *               membar_storestore_0Node::pipeline() const { return (&pipeline_class_044); }

const Pipeline *               membar_release_lockNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *               membar_release_lockNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                   membar_volatileNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                   membar_volatileNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                           castX2PNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                           castX2PNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                           castP2XNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                           castP2XNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                            castPPNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                            castPPNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                            castLLNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                            castLLNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                            castIINode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                            castIINode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                       checkCastPPNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                       checkCastPPNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                            castFFNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                            castFFNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                            castDDNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                            castDDNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                            castVVNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                            castVVNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                        convI2BoolNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        convI2BoolNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        convP2BoolNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        convP2BoolNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                   convI2L_reg_regNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                   convI2L_reg_regNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                       convL2I_regNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                       convL2I_regNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                  convI2UL_reg_regNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                  convI2UL_reg_regNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                       convF2D_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                       convF2D_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                       convD2F_regNode::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                       convD2F_regNode::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                   convF2I_reg_regNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                   convF2I_reg_regNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                   convI2F_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                   convI2F_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                   convF2L_reg_regNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                   convF2L_reg_regNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                   convL2F_reg_regNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                   convL2F_reg_regNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *                   convD2I_reg_regNode::pipeline_class() { return (&pipeline_class_011); }
const Pipeline *                   convD2I_reg_regNode::pipeline() const { return (&pipeline_class_011); }

const Pipeline *                   convI2D_reg_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                   convI2D_reg_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                   convD2L_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                   convD2L_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                   convL2D_reg_regNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                   convL2D_reg_regNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                           convP2INode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                           convP2INode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                           convN2INode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                           convN2INode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                     encodeHeapOopNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     encodeHeapOopNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                     decodeHeapOopNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     decodeHeapOopNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *            decodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *            decodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *              encodeKlass_not_nullNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *              encodeKlass_not_nullNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *              decodeKlass_not_nullNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *              decodeKlass_not_nullNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                 MoveF2I_stack_regNode::pipeline_class() { return (&pipeline_class_036); }
const Pipeline *                 MoveF2I_stack_regNode::pipeline() const { return (&pipeline_class_036); }

const Pipeline *                 MoveI2F_stack_regNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                 MoveI2F_stack_regNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                 MoveD2L_stack_regNode::pipeline_class() { return (&pipeline_class_036); }
const Pipeline *                 MoveD2L_stack_regNode::pipeline() const { return (&pipeline_class_036); }

const Pipeline *                 MoveL2D_stack_regNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                 MoveL2D_stack_regNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                 MoveF2I_reg_stackNode::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                 MoveF2I_reg_stackNode::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                 MoveI2F_reg_stackNode::pipeline_class() { return (&pipeline_class_039); }
const Pipeline *                 MoveI2F_reg_stackNode::pipeline() const { return (&pipeline_class_039); }

const Pipeline *                 MoveD2L_reg_stackNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                 MoveD2L_reg_stackNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                 MoveL2D_reg_stackNode::pipeline_class() { return (&pipeline_class_039); }
const Pipeline *                 MoveL2D_reg_stackNode::pipeline() const { return (&pipeline_class_039); }

const Pipeline *                   MoveF2I_reg_regNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                   MoveF2I_reg_regNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                   MoveI2F_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                   MoveI2F_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                   MoveD2L_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                   MoveD2L_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                   MoveL2D_reg_regNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                   MoveL2D_reg_regNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                     cmpF3_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     cmpF3_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                     cmpD3_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     cmpD3_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                     cmpL3_reg_regNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                     cmpL3_reg_regNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                 cmpLTMask_reg_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                 cmpLTMask_reg_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                cmpLTMask_reg_zeroNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                cmpLTMask_reg_zeroNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                      minI_reg_regNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                      minI_reg_regNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                      maxI_reg_regNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                      maxI_reg_regNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                     minI_reg_zeroNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                     minI_reg_zeroNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                   minI_reg_zero_0Node::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                   minI_reg_zero_0Node::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                     maxI_reg_zeroNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                     maxI_reg_zeroNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                   maxI_reg_zero_0Node::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                   maxI_reg_zero_0Node::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                         minI_rRegNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                         minI_rRegNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                         maxI_rRegNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                         maxI_rRegNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                            branchNode::pipeline_class() { return (&pipeline_class_040); }
const Pipeline *                            branchNode::pipeline() const { return (&pipeline_class_040); }

const Pipeline *                    cmpFlag_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                    cmpFlag_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                       cmpI_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                       cmpI_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                         cmpI_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                         cmpI_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                       cmpU_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                       cmpU_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                         cmpU_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                         cmpU_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                       cmpL_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                       cmpL_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                         cmpL_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                         cmpL_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                      cmpUL_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                      cmpUL_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                        cmpUL_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                        cmpUL_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                       cmpP_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                       cmpP_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                         cmpP_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                         cmpP_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                       cmpN_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                       cmpN_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                         cmpN_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                         cmpN_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                       cmpF_branchNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                       cmpF_branchNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                         cmpF_loopNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                         cmpF_loopNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                       cmpD_branchNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                       cmpD_branchNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                         cmpD_loopNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                         cmpD_loopNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *              cmpI_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *              cmpI_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                cmpI_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                cmpI_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *      cmpUEqNeLeGt_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *      cmpUEqNeLeGt_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *        cmpUEqNeLeGt_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *        cmpUEqNeLeGt_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *              cmpL_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *              cmpL_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                cmpL_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                cmpL_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *     cmpULEqNeLeGt_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *     cmpULEqNeLeGt_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *       cmpULEqNeLeGt_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *       cmpULEqNeLeGt_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                  cmpP_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                  cmpP_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                    cmpP_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                    cmpP_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                  cmpN_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                  cmpN_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                    cmpN_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                    cmpN_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *        cmpP_narrowOop_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *        cmpP_narrowOop_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *          cmpP_narrowOop_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *          cmpP_narrowOop_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                far_cmpFlag_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                far_cmpFlag_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                   far_cmpI_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                   far_cmpI_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                     far_cmpI_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                     far_cmpI_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                   far_cmpU_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                   far_cmpU_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                     far_cmpU_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                     far_cmpU_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                   far_cmpL_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                   far_cmpL_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                      far_cmpLloopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                      far_cmpLloopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                  far_cmpUL_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                  far_cmpUL_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                    far_cmpUL_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                    far_cmpUL_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                   far_cmpP_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                   far_cmpP_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                     far_cmpP_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                     far_cmpP_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                   far_cmpN_branchNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                   far_cmpN_branchNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                     far_cmpN_loopNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                     far_cmpN_loopNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                   far_cmpF_branchNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                   far_cmpF_branchNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                     far_cmpF_loopNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                     far_cmpF_loopNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                   far_cmpD_branchNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                   far_cmpD_branchNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                     far_cmpD_loopNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                     far_cmpD_loopNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *          far_cmpI_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *          far_cmpI_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *            far_cmpI_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *            far_cmpI_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *      far_cmpUEqNeLeGt_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *      far_cmpUEqNeLeGt_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *    far_cmpUEqNeLeGt_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *    far_cmpUEqNeLeGt_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *      far_cmpULtGe_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *      far_cmpULtGe_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *        far_cmpULtGe_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *        far_cmpULtGe_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *          far_cmpL_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *          far_cmpL_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *            far_cmpL_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *            far_cmpL_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline * far_cmpULEqNeLeGt_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline * far_cmpULEqNeLeGt_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *   far_cmpULEqNeLeGt_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *   far_cmpULEqNeLeGt_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *     far_cmpULLtGe_reg_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *     far_cmpULLtGe_reg_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *       far_cmpULLtGe_reg_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *       far_cmpULLtGe_reg_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *              far_cmpP_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *              far_cmpP_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                far_cmpP_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                far_cmpP_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *              far_cmpN_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *              far_cmpN_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                far_cmpN_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                far_cmpN_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *    far_cmpP_narrowOop_imm0_branchNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *    far_cmpP_narrowOop_imm0_branchNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *      far_cmpP_narrowOop_imm0_loopNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *      far_cmpP_narrowOop_imm0_loopNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                        cmovI_cmpINode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                        cmovI_cmpINode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                        cmovI_cmpUNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                        cmovI_cmpUNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                        cmovI_cmpLNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                        cmovI_cmpLNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                       cmovI_cmpULNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                       cmovI_cmpULNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                        cmovL_cmpLNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                        cmovL_cmpLNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                       cmovL_cmpULNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                       cmovL_cmpULNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                        cmovL_cmpINode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                        cmovL_cmpINode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                        cmovL_cmpUNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *                        cmovL_cmpUNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *              CallStaticJavaDirectNode::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *              CallStaticJavaDirectNode::pipeline() const { return (&pipeline_class_050); }

const Pipeline *             CallDynamicJavaDirectNode::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *             CallDynamicJavaDirectNode::pipeline() const { return (&pipeline_class_050); }

const Pipeline *                 CallRuntimeDirectNode::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *                 CallRuntimeDirectNode::pipeline() const { return (&pipeline_class_050); }

const Pipeline *                    CallLeafDirectNode::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *                    CallLeafDirectNode::pipeline() const { return (&pipeline_class_050); }

const Pipeline *                CallLeafNoFPDirectNode::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *                CallLeafNoFPDirectNode::pipeline() const { return (&pipeline_class_050); }

const Pipeline *               partialSubtypeCheckNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *               partialSubtypeCheckNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *         partialSubtypeCheckVsZeroNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *         partialSubtypeCheckVsZeroNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                   string_compareUNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                   string_compareUNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                   string_compareLNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                   string_compareLNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                  string_compareULNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                  string_compareULNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                  string_compareLUNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                  string_compareLUNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                  string_indexofUUNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                  string_indexofUUNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                  string_indexofLLNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                  string_indexofLLNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                  string_indexofULNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                  string_indexofULNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *              string_indexof_conUUNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *              string_indexof_conUUNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *              string_indexof_conLLNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *              string_indexof_conLLNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *              string_indexof_conULNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *              string_indexof_conULNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *              stringU_indexof_charNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *              stringU_indexof_charNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *              stringL_indexof_charNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *              stringL_indexof_charNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                clearArray_reg_regNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                clearArray_reg_regNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                clearArray_imm_regNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                clearArray_imm_regNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                    string_equalsLNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                    string_equalsLNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                    string_equalsUNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                    string_equalsUNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                     array_equalsBNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                     array_equalsBNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                     array_equalsCNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                     array_equalsCNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                         safePointNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                         safePointNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                          tlsLoadPNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                          tlsLoadPNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                       cmpFastLockNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                       cmpFastLockNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                     cmpFastUnlockNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                     cmpFastUnlockNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                    TailCalljmpIndNode::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *                    TailCalljmpIndNode::pipeline() const { return (&pipeline_class_050); }

const Pipeline *                        TailjmpIndNode::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *                        TailjmpIndNode::pipeline() const { return (&pipeline_class_050); }

const Pipeline *                   CreateExceptionNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                   CreateExceptionNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                  RethrowExceptionNode::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *                  RethrowExceptionNode::pipeline() const { return (&pipeline_class_050); }

const Pipeline *                               RetNode::pipeline_class() { return (&pipeline_class_040); }
const Pipeline *                               RetNode::pipeline() const { return (&pipeline_class_040); }

const Pipeline *                ShouldNotReachHereNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *                ShouldNotReachHereNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *                             loadVNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             loadVNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                            storeVNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                            storeVNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vabsBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vabsBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vabsSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vabsSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vabsINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vabsINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vabsLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vabsLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vabsFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vabsFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vabsDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vabsDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vaddBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vaddBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vaddSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vaddSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vaddINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vaddINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vaddLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vaddLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vaddFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vaddFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vaddDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vaddDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                              vandNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                              vandNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                               vorNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                               vorNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                              vxorNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                              vxorNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vdivFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vdivFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vdivDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vdivDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                              vmaxNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                              vmaxNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                              vminNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                              vminNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmaxFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmaxFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmaxDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmaxDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vminFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vminFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vminDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vminDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                            vfmlaFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                            vfmlaFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                            vfmlaDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                            vfmlaDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                            vfmlsFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                            vfmlsFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                          vfmlsF_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                          vfmlsF_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                            vfmlsDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                            vfmlsDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                          vfmlsD_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                          vfmlsD_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                           vfnmlaFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                           vfnmlaFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vfnmlaF_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vfnmlaF_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                           vfnmlaDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                           vfnmlaDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vfnmlaD_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vfnmlaD_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                           vfnmlsFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                           vfnmlsFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                           vfnmlsDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                           vfnmlsDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmlaBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmlaBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                           vmlaB_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                           vmlaB_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmlaSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmlaSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                           vmlaS_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                           vmlaS_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmlaINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmlaINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                           vmlaI_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                           vmlaI_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmlaLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmlaLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                           vmlaL_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                           vmlaL_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmlsBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmlsBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmlsSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmlsSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmlsINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmlsINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmlsLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmlsLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmulBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmulBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmulSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmulSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmulINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmulINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmulLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmulLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmulFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmulFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vmulDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vmulDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vnegFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vnegFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vnegDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vnegDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                       reduce_addBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                       reduce_addBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                       reduce_addSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                       reduce_addSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                       reduce_addINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                       reduce_addINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                       reduce_addLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                       reduce_addLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                       reduce_addFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                       reduce_addFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                       reduce_addDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                       reduce_addDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_maxBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_maxBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_maxSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_maxSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_maxINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_maxINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_maxLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_maxLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_minBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_minBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_minSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_minSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_minINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_minINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_minLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_minLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_maxFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_maxFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_maxDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_maxDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_minFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_minFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vreduce_minDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vreduce_minDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        replicateBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        replicateBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        replicateSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        replicateSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        replicateINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        replicateINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        replicateLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        replicateLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   replicateB_imm5Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   replicateB_imm5Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   replicateS_imm5Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   replicateS_imm5Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   replicateI_imm5Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   replicateI_imm5Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   replicateL_imm5Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   replicateL_imm5Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        replicateFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        replicateFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        replicateDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        replicateDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vasrBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vasrBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vasrSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vasrSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vasrINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vasrINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vasrLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vasrLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vlslBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vlslBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vlslSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vlslSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vlslINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vlslINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vlslLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vlslLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vlsrBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vlsrBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vlsrSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vlsrSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vlsrINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vlsrINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vlsrLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vlsrLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vasrB_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vasrB_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vasrS_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vasrS_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vasrI_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vasrI_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vasrL_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vasrL_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vlsrB_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vlsrB_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vlsrS_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vlsrS_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vlsrI_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vlsrI_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vlsrL_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vlsrL_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vlslB_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vlslB_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vlslS_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vlslS_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vlslI_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vlslI_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                         vlslL_immNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                         vlslL_immNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        vshiftcntBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        vshiftcntBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vshiftcntB_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vshiftcntB_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        vshiftcntSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        vshiftcntSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vshiftcntS_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vshiftcntS_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        vshiftcntINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        vshiftcntINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vshiftcntI_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vshiftcntI_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                        vshiftcntLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                        vshiftcntLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                      vshiftcntL_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                      vshiftcntL_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                            vsqrtFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                            vsqrtFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                            vsqrtDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                            vsqrtDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vsubBNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vsubBNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vsubSNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vsubSNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vsubINode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vsubINode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vsubLNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vsubLNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vsubFNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vsubFNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                             vsubDNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                             vsubDNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   vstring_equalsLNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                   vstring_equalsLNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                   vstring_equalsUNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                   vstring_equalsUNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                    varray_equalsBNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                    varray_equalsBNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                    varray_equalsCNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                    varray_equalsCNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                  vstring_compareUNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                  vstring_compareUNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                  vstring_compareLNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                  vstring_compareLNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                 vstring_compareULNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                 vstring_compareULNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                 vstring_compareLUNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                 vstring_compareLUNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                   vstring_inflateNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                   vstring_inflateNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                 vencode_iso_arrayNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                 vencode_iso_arrayNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *               vencode_ascii_arrayNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *               vencode_ascii_arrayNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                  vstring_compressNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                  vstring_compressNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                    vhas_negativesNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                    vhas_negativesNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *             vstringU_indexof_charNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *             vstringU_indexof_charNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *             vstringL_indexof_charNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *             vstringL_indexof_charNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *               vclearArray_reg_regNode::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *               vclearArray_reg_regNode::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                        rorI_imm_bNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                        rorI_imm_bNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                        rorL_imm_bNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                        rorL_imm_bNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                        rorI_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        rorI_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        rorL_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        rorL_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        rolI_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        rolI_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        rolL_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        rolL_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                         convP2I_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                         convP2I_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                 convB2I_reg_reg_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 convB2I_reg_reg_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                 convI2S_reg_reg_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 convI2S_reg_reg_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                convS2UI_reg_reg_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                convS2UI_reg_reg_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                convI2UL_reg_reg_bNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                convI2UL_reg_reg_bNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *               bytes_reverse_int_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *               bytes_reverse_int_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *              bytes_reverse_long_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *              bytes_reverse_long_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *    bytes_reverse_unsigned_short_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *    bytes_reverse_unsigned_short_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *             bytes_reverse_short_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *             bytes_reverse_short_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                  shaddP_reg_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                  shaddP_reg_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *              shaddP_reg_reg_ext_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *              shaddP_reg_reg_ext_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                  shaddL_reg_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                  shaddL_reg_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                shaddL_reg_reg_b_0Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                shaddL_reg_reg_b_0Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *              shaddL_reg_reg_ext_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *              shaddL_reg_reg_ext_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *            shaddL_reg_reg_ext_b_0Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *            shaddL_reg_reg_ext_b_0Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *              countLeadingZerosI_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *              countLeadingZerosI_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *              countLeadingZerosL_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *              countLeadingZerosL_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *             countTrailingZerosI_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *             countTrailingZerosI_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *             countTrailingZerosL_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *             countTrailingZerosL_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                       popCountI_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                       popCountI_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                       popCountL_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                       popCountL_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                    minI_reg_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                    minI_reg_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                    maxI_reg_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                    maxI_reg_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                   minI_reg_zero_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                   minI_reg_zero_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                 minI_reg_zero_b_0Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                 minI_reg_zero_b_0Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                   maxI_reg_zero_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                   maxI_reg_zero_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                 maxI_reg_zero_b_0Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                 maxI_reg_zero_b_0Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        absI_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        absI_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        absL_reg_bNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        absL_reg_bNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                   andnI_reg_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                   andnI_reg_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                 andnI_reg_reg_b_0Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                 andnI_reg_reg_b_0Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                   andnL_reg_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                   andnL_reg_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                 andnL_reg_reg_b_0Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                 andnL_reg_reg_b_0Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                    ornI_reg_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                    ornI_reg_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                  ornI_reg_reg_b_0Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                  ornI_reg_reg_b_0Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                    ornL_reg_reg_bNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                    ornL_reg_reg_bNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                  ornL_reg_reg_b_0Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                  ornL_reg_reg_b_0Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *  convI2Bool_andI_reg_immIpowerOf2Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *  convI2Bool_andI_reg_immIpowerOf2Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *        compareAndSwapP_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *        compareAndSwapP_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *        compareAndSwapN_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *        compareAndSwapN_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *     compareAndSwapPAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *     compareAndSwapPAcq_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *     compareAndSwapNAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *     compareAndSwapNAcq_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *    compareAndExchangeN_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *    compareAndExchangeN_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *    compareAndExchangeP_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *    compareAndExchangeP_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *    weakCompareAndSwapN_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *    weakCompareAndSwapN_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline * compareAndExchangeNAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline * compareAndExchangeNAcq_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline * compareAndExchangePAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline * compareAndExchangePAcq_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *    weakCompareAndSwapP_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *    weakCompareAndSwapP_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline * weakCompareAndSwapNAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline * weakCompareAndSwapNAcq_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline * weakCompareAndSwapPAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline * weakCompareAndSwapPAcq_shenandoahNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                            zLoadPNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                            zLoadPNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                  zCompareAndSwapPNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                  zCompareAndSwapPNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                zCompareAndSwapP_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                zCompareAndSwapP_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *               zCompareAndSwapPAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *               zCompareAndSwapPAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *             zCompareAndSwapPAcq_0Node::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *             zCompareAndSwapPAcq_0Node::pipeline() const { return (&pipeline_class_045); }

const Pipeline *              zCompareAndExchangePNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *              zCompareAndExchangePNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *           zCompareAndExchangePAcqNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *           zCompareAndExchangePAcqNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                       zGetAndSetPNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                       zGetAndSetPNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                    zGetAndSetPAcqNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                    zGetAndSetPAcqNode::pipeline() const { return (&pipeline_class_044); }
// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DRISCV64=1
#ifndef RISCV64
#  error "RISCV64 must be defined"
#endif // RISCV64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
